@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Six Apart Ltd.
+# Copyright (c) 2009-2010 Six Apart Ltd.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -242,12 +242,18 @@ class Request(object):
                     return self.http
 
             class CaptureHTTPConnection(object):
+                def connect(self):
+                    pass
+
                 def request(self, method, request_uri, body, headers):
                     self.url     = request_uri
                     self.body    = body
                     self.headers = headers
                     raise StopCharade()
 
+                def close(self):
+                    pass
+
             real_connections = http.connections
             conns = CaptureConnections()
             conn = CaptureHTTPConnection()
@@ -275,6 +281,9 @@ class Request(object):
                     return self.http
 
             class HandoffHTTPConnection(object):
+                def connect(self):
+                    pass
+
                 def request(self, method, request_uri, body, headers):
                     pass
 
@@ -284,6 +293,9 @@ class Request(object):
                 def getresponse(self):
                     return self
 
+                def close(self):
+                    pass
+
                 def __getattr__(self, key):
                     return getattr(response, key)
 
